@@ -140,9 +140,9 @@ accepting many types of data, or diagnostic tools for debugging IPFIX export:
 >>> for rec in msg.namedict_iterator():
 ...    print(sorted(rec.items()))
 ...
-[('destinationIPv4Address', IPv4Address('10.5.6.7')), ('flowStartMilliseconds', datetime.datetime(2013, 6, 21, 12, 0, tzinfo=datetime.timezone.utc)), ('packetDeltaCount', 27), ('sourceIPv4Address', IPv4Address('10.1.2.3'))]
-[('destinationIPv4Address', IPv4Address('10.12.13.14')), ('flowStartMilliseconds', datetime.datetime(2013, 6, 21, 12, 0, 2, tzinfo=datetime.timezone.utc)), ('packetDeltaCount', 33), ('sourceIPv4Address', IPv4Address('10.8.9.11'))]
-[('flowStartMilliseconds', datetime.datetime(2013, 6, 21, 12, 0, 4, tzinfo=datetime.timezone.utc)), ('myNewInformationElement', "Grüezi, Y'all")]
+[('destinationIPv4Address', IPv4Address('10.5.6.7')), ('flowStartMilliseconds', datetime.datetime(2013, 6, 21, 14, 0)), ('packetDeltaCount', 27), ('sourceIPv4Address', IPv4Address('10.1.2.3'))]
+[('destinationIPv4Address', IPv4Address('10.12.13.14')), ('flowStartMilliseconds', datetime.datetime(2013, 6, 21, 14, 0, 2)), ('packetDeltaCount', 33), ('sourceIPv4Address', IPv4Address('10.8.9.11'))]
+[('flowStartMilliseconds', datetime.datetime(2013, 6, 21, 14, 0, 4)), ('myNewInformationElement', "Grüezi, Y'all")]
 
 The tuple interface for reading messages is designed for applications with a
 specific internal data model. It can be much faster than the dictionary
@@ -155,8 +155,8 @@ specified as an :class:`ipfix.ie.InformationElementList` instance, from
 >>> for rec in msg.tuple_iterator(ielist):
 ...     print(rec)
 ...
-(datetime.datetime(2013, 6, 21, 12, 0, tzinfo=datetime.timezone.utc), 27)
-(datetime.datetime(2013, 6, 21, 12, 0, 2, tzinfo=datetime.timezone.utc), 33)
+(datetime.datetime(2013, 6, 21, 14, 0), 27)
+(datetime.datetime(2013, 6, 21, 14, 0, 2), 33)
 
 Notice that the variable-length record written to the message are not returned 
 by this iterator, since that record doesn't include a packetDeltaCount IE. 
@@ -225,6 +225,8 @@ class MessageBuffer:
         
         self.mtu = 65535
         
+        self.add_template_hook = None
+        
     def __repr__(self):
         if self.cursetid:
             addinf = " (writing set "+str(self.cursetid)+")"
@@ -401,9 +403,11 @@ class MessageBuffer:
                         self.accepted_tids.add((self.odid, tmpl.tid))
                     else:
                         self.accepted_tids.discard((self.odid, tmpl.tid))
+                    if self.add_template_hook:
+                        self.add_template_hook(self, tmpl)
                     
             elif setid < 256:
-                warn("skipping illegal set id "+setid)
+                warn("skipping illegal set id "+str(setid))
             elif (self.odid, setid) in self.accepted_tids:
                 try:
                     tmpl = self.templates[(self.odid, setid)]
@@ -505,8 +509,12 @@ class MessageBuffer:
         :raises: EndOfMessage
         """
         self.templates[(self.odid, tmpl.tid)] = tmpl
+        
         if export:
             self.export_template(tmpl.tid)
+        
+        if self.add_template_hook:
+            self.add_template_hook(self, tmpl)
     
     def delete_template(self, tid, export=True):
         """
