@@ -27,6 +27,7 @@
 from . import message
 from . import template
 from . import types
+from datetime import datetime
 
 import math
 
@@ -41,7 +42,7 @@ def scale_tupletuple(tt, scale):
     return tuple([scale_tuple(x, scale) for x in tt])
 
 def render_dt8601(dt):
-    return dt.strftime("%Y-%m-%d %H:%M:%S")
+    return dt.strftime("%Y-%m-%d %H:%M:%S.%f %Z")
 
 def render_ienumber(ie):
     if ie.pen:
@@ -172,8 +173,8 @@ class OctetFieldDrawing:
     def add(self, length, value,
             render_fn=str, label=None, rowbreak=False):
         
-        # Increment row on rowbreak
-        if rowbreak and self.col:
+        # Increment row on rowbreak, or at end of row
+        if (self.col >= self.raster) or (rowbreak and self.col):
             self.row += 1
             self.rowaddrs.append(self.rowaddrs[-1] + self.col)
             self.col = 0
@@ -199,7 +200,7 @@ class OctetFieldDrawing:
         elif self.col == 0 and length > self.raster:
             # Case 1a: even multiple, multirow rect
             if length % self.raster == 0:
-                #print("    perfect fit, multirow rect")
+                #print("    perfect fit, "+str(length/self.raster)+"-row rect")
                 self._add_field(length, 
                                 RectField(self.col, self.row, 
                                           self.raster, length / self.raster,
@@ -388,7 +389,10 @@ class MessageBufferRenderer:
             else:
                 label = midtrunc(ie.name,8,8)
             
-            self.ofd.add(ielen, v, label=label)
+            if isinstance(v, datetime):
+                self.ofd.add(ielen, v, render_fn=render_dt8601, label=label)
+            else:
+                self.ofd.add(ielen, v, label=label)
         
         return offset
             
@@ -449,8 +453,8 @@ class MessageBufferRenderer:
         return self.ofd.render(self.scale)
 
 class MessageStreamRenderer(MessageBufferRenderer):
-    def __init__(self, stream, scale):
-        super().__init__(message.MessageBuffer(), scale)
+    def __init__(self, stream, scale=(90,30), raster=8):
+        super().__init__(message.MessageBuffer(), scale, raster)
         self.stream = stream
         
     def render_next_message(self, length=65535):
